stacktest

package
v0.15.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ResetServices

func ResetServices()

ResetServices unlocks and resets (clears) the registered stack services.

Only use this in test harnesses, and be careful.

CLI commands generated from the registered services will not be reset / regenerated, so the uses of this are limited.

Running this while the stack is running WILL cause problems.

Types

This section is empty.

Jump to