Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ResetServices ¶
func ResetServices()
ResetServices unlocks and resets (clears) the registered stack services.
Only use this in test harnesses, and be careful.
CLI commands generated from the registered services will not be reset / regenerated, so the uses of this are limited.
Running this while the stack is running WILL cause problems.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.